@@ -23,6 +23,14 @@
 
 #include <glib.h>
 #include <goffice/goffice-features.h>
+#include <hildon-fm-2/hildon/hildon-file-chooser-dialog.h>
+
+#ifdef GOFFICE_WITH_GTK
+#include <gtk/gtk.h>
+#else
+#include <cairo/cairo.h>
+#include <pango/pango.h>
+#endif
 
 #ifndef GO_VAR_DECL
 #  ifdef WIN32
