@@ -22,6 +22,7 @@
 #include <goffice/goffice-config.h>
 #include <goffice/goffice.h>
 #include <goffice/goffice-priv.h>
+#include <goffice/gtk/go-gtk-compat.h>
 
 #include <gdk/gdkkeysyms.h>
 #include <atk/atkrelation.h>
@@ -89,7 +90,7 @@ go_gtk_dialog_add_button (GtkDialog *dialog, char const* text, char const* stock
 	button = go_gtk_button_new_with_stock (text, stock_id);
 	g_return_val_if_fail (button != NULL, NULL);
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button, TRUE);
 
 	gtk_widget_show (button);
 
@@ -139,7 +140,8 @@ go_gtk_builder_new (char const *uifile,
 			msg = g_strdup_printf (_("Unable to open file '%s'"), f);
 		go_cmd_context_error_system (gcc, msg);
 		g_free (msg);
-	}
+	} else if (error)
+		g_error_free (error);
 	g_free (f);
 
 	return gui;
@@ -268,8 +270,9 @@ go_gtk_builder_group_value (GtkBuilder *gui, char const * const group[])
 static void
 cb_activate_default (GtkWindow *window)
 {
-	if (window->default_widget && GTK_WIDGET_IS_SENSITIVE (window->default_widget))
-		gtk_widget_activate (window->default_widget);
+	GtkWidget *w = gtk_window_get_default_widget (window);
+	if (w && gtk_widget_is_sensitive (w))
+		gtk_widget_activate (w);
 }
 
 /**
@@ -304,7 +307,7 @@ go_gtk_widget_disable_focus (GtkWidget *w)
 	if (GTK_IS_CONTAINER (w))
 		gtk_container_foreach (GTK_CONTAINER (w),
 			(GtkCallback) go_gtk_widget_disable_focus, NULL);
-	GTK_WIDGET_UNSET_FLAGS (w, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (w, FALSE);
 }
 
 /**
@@ -335,7 +338,7 @@ go_pango_measure_string (PangoContext *context, PangoFontDescription const *font
 static void
 cb_parent_mapped (GtkWidget *parent, GtkWindow *window)
 {
-	if (GTK_WIDGET_MAPPED (window)) {
+	if (gtk_widget_get_mapped (GTK_WIDGET (window))) {
 		gtk_window_present (window);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (parent),
 			G_CALLBACK (cb_parent_mapped), window);
@@ -370,7 +373,7 @@ go_gtk_window_set_transient (GtkWindow *toplevel, GtkWindow *window)
 
 	gtk_window_set_position (window, position);
 
-	if (!GTK_WIDGET_MAPPED (toplevel))
+	if (!gtk_widget_get_mapped (GTK_WIDGET (toplevel)))
 		g_signal_connect_after (G_OBJECT (toplevel),
 			"map",
 			G_CALLBACK (cb_parent_mapped), window);
@@ -567,6 +570,9 @@ gui_image_chooser_new (gboolean is_save)
 {
 	GtkFileChooser *fsel;
 
+/* Use Maemo File Chooser */
+	fsel = GTK_FILE_CHOOSER (hildon_file_chooser_dialog_new (NULL,is_save ? GTK_FILE_CHOOSER_ACTION_SAVE : GTK_FILE_CHOOSER_ACTION_OPEN));
+/*
 	fsel = GTK_FILE_CHOOSER
 		(g_object_new (GTK_TYPE_FILE_CHOOSER_DIALOG,
 			       "action", is_save ? GTK_FILE_CHOOSER_ACTION_SAVE : GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -578,6 +584,8 @@ gui_image_chooser_new (gboolean is_save)
 				is_save ? GTK_STOCK_SAVE : GTK_STOCK_OPEN,
 				GTK_RESPONSE_OK,
 				NULL);
+*/
+
 	gtk_dialog_set_default_response (GTK_DIALOG (fsel), GTK_RESPONSE_OK);
 	/* Filters */
 	{
@@ -597,7 +605,7 @@ gui_image_chooser_new (gboolean is_save)
 		gtk_file_chooser_set_filter (fsel, filter);
 	}
 
-	/* Preview */
+	/* Preview *//*
 	{
 		GtkWidget *vbox = gtk_vbox_new (FALSE, 2);
 		GtkWidget *preview_image = gtk_image_new ();
@@ -614,7 +622,7 @@ gui_image_chooser_new (gboolean is_save)
 		g_signal_connect (fsel, "update-preview",
 				  G_CALLBACK (update_preview_cb), NULL);
 		update_preview_cb (fsel);
-	}
+	}*/
 	return fsel;
 }
 
@@ -707,10 +715,11 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 		state->uri = NULL;
 		state->resolution = 150.0;
 		state->is_expanded = FALSE;
-		state->format = GO_IMAGE_FORMAT_SVG;
+/* Maemo 5: changed from GO_IMAGE_FORMAT_SVG to GO_IMAGE_FORMAT_JPG */
+		state->format = GO_IMAGE_FORMAT_JPG;
 		g_object_set_data_full (G_OBJECT (toplevel), key,
 					state, (GDestroyNotify) save_info_state_free);
-	}
+	}	       
 
 	g_object_set (G_OBJECT (fsel), "title", _("Save as"), NULL);
 
@@ -725,7 +734,8 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			GSList *l;
 			format_combo = go_gtk_builder_combo_box_init_text (gui, "format_combo");
 			for (l = supported_formats, i = 0; l != NULL; l = l->next, i++) {
-				format = GPOINTER_TO_UINT (l->data);
+				/* Maemo 5 change */
+				format = GO_IMAGE_FORMAT_JPG;
 				format_info = go_image_get_format_info (format);
 				gtk_combo_box_append_text (format_combo, _(format_info->desc));
 				if (format == state->format)
@@ -776,9 +786,8 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 	if (format_combo) {
 		char *new_uri = NULL;
 
-		format = GPOINTER_TO_UINT (g_slist_nth_data
-			(supported_formats,
-			 gtk_combo_box_get_active (format_combo)));
+		/* Maemo 5 change */
+		format = GO_IMAGE_FORMAT_JPG;
 		format_info = go_image_get_format_info (format);
 		if (!go_url_check_extension (uri, format_info->ext, &new_uri) &&
 		    !go_gtk_query_yes_no (GTK_WINDOW (fsel), TRUE,
@@ -910,7 +919,7 @@ go_help_display (CBHelpPaths const *paths)
 							      i, path, line);
 					continue;
 				}
-				for (; *topic == ' '; ++topic);
+				for (; *topic == ' ' || *topic == '\t'; ++topic);
 				g_hash_table_insert (context_help_map, g_strdup (topic),
 					(gpointer)id);
 			}
@@ -1080,10 +1089,9 @@ go_gtk_notice_dialog (GtkWindow *parent, GtkMessageType type,
 	GtkWidget *dialog;
 
 	VPRINTF_MESSAGE (format, args, msg);
-	dialog = gtk_message_dialog_new (parent,
+	dialog = gtk_message_dialog_new_with_markup (parent,
 		GTK_DIALOG_DESTROY_WITH_PARENT, type, GTK_BUTTONS_OK, "%s", msg);
 	g_free (msg);
-	gtk_label_set_use_markup (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label), TRUE);
 	go_gtk_dialog_run (GTK_DIALOG (dialog), parent);
 }
 
@@ -1216,7 +1224,7 @@ go_dialog_guess_alternative_button_order (GtkDialog *dialog)
 	gboolean any = FALSE;
 	int loops = 0;
 
-	children = gtk_container_get_children (GTK_CONTAINER (dialog->action_area));
+	children = gtk_container_get_children (GTK_CONTAINER (gtk_dialog_get_action_area (dialog)));
 	if (!children)
 		return;
 
@@ -1294,13 +1302,20 @@ go_menu_position_below (GtkMenu  *menu,
 	GdkScreen *screen;
 	gint monitor_num;
 	GdkRectangle monitor;
+	GdkWindow *window = gtk_widget_get_window (widget);
+	GtkAllocation size;
 
-	gdk_window_get_origin (widget->window, &sx, &sy);
+	gtk_widget_get_allocation (widget, &size);
 
-	if (GTK_WIDGET_NO_WINDOW (widget))
+	if (window)
+		gdk_window_get_origin (window, &sx, &sy);
+	else
+		sx = sy = 0;
+
+	if (!gtk_widget_get_has_window (widget))
 	{
-		sx += widget->allocation.x;
-		sy += widget->allocation.y;
+		sx += size.x;
+		sy += size.y;
 	}
 
 	gtk_widget_size_request (GTK_WIDGET (menu), &req);
@@ -1308,11 +1323,11 @@ go_menu_position_below (GtkMenu  *menu,
 	if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR)
 		*x = sx;
 	else
-		*x = sx + widget->allocation.width - req.width;
+		*x = sx + size.width - req.width;
 	*y = sy;
 
 	screen = gtk_widget_get_screen (widget);
-	monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
+	monitor_num = gdk_screen_get_monitor_at_window (screen, window);
 	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
 	if (*x < monitor.x)
@@ -1320,12 +1335,12 @@ go_menu_position_below (GtkMenu  *menu,
 	else if (*x + req.width > monitor.x + monitor.width)
 		*x = monitor.x + monitor.width - req.width;
 
-	if (monitor.y + monitor.height - *y - widget->allocation.height >= req.height)
-		*y += widget->allocation.height;
+	if (monitor.y + monitor.height - *y - size.height >= req.height)
+		*y +=size.height;
 	else if (*y - monitor.y >= req.height)
 		*y -= req.height;
-	else if (monitor.y + monitor.height - *y - widget->allocation.height > *y - monitor.y)
-		*y += widget->allocation.height;
+	else if (monitor.y + monitor.height - *y - size.height > *y - monitor.y)
+		*y += size.height;
 	else
 		*y -= req.height;
 
